@@ -21,7 +21,7 @@
 
 int pmpd2d_test_2d_mass(int i, t_pmpd2d *x, int argc, t_atom *argv)
 {
-// TODO : check arg number and type befor using them
+// TODO : check arg number and type before using them
 
 	t_float tmp;
 	t_int j = 1, k;
@@ -249,7 +249,7 @@ int pmpd2d_test_2d_mass(int i, t_pmpd2d *x, int argc, t_atom *argv)
             }
 			else
 			{
-				pd_error(x, "Option \"%s\" not reconized, stoping test",atom_getsymbolarg(j,argc,argv)->s_name);
+				pd_error(x, "Option \"%s\" not recognized, stopping test",atom_getsymbolarg(j,argc,argv)->s_name);
 				return(-1);
 			}
 		}
@@ -397,7 +397,7 @@ int pmpd2d_test_2d_link(int i, t_pmpd2d *x, int argc, t_atom *argv)
             }
 			else
 			{
-				pd_error(x,"Option \"%s\" not reconized, stoping test",atom_getsymbolarg(j,argc,argv)->s_name);
+				pd_error(x,"Option \"%s\" not recognized, stopping test",atom_getsymbolarg(j,argc,argv)->s_name);
 				return(-1);
 			}
 		}
