@@ -202,7 +202,7 @@ int pmpd_test_1d_mass(int i, t_pmpd *x, int argc, t_atom *argv)
 			}
 			else
 			{
-				pd_error(x,"Option \"%s\" not reconized, stoping test",atom_getsymbolarg(j,argc,argv)->s_name);
+				pd_error(x,"Option \"%s\" not recognized, stopping test",atom_getsymbolarg(j,argc,argv)->s_name);
 				return(-1);
 			}
 		}
@@ -309,7 +309,7 @@ int pmpd_test_1d_link(int i, t_pmpd *x, int argc, t_atom *argv)
 			}
 			else
 			{
-				pd_error(x,"Option \"%s\" not reconized, stoping test",atom_getsymbolarg(j,argc,argv)->s_name);
+				pd_error(x,"Option \"%s\" not recognized, stopping test",atom_getsymbolarg(j,argc,argv)->s_name);
 				return(-1);
 			}
 		}
